@@ -1470,3 +1470,36 @@ class APIVisitor(APIParserVisitor):
         self.parsedObject = parsedObject
         self.errorCode = errorCode
         self.errorMsg = errorMsg
+
+    def visitPlugin(self, ctx: APIParser.PluginContext):
+        parsedObject = {'name': 'PLUGIN'}
+
+        pluginName = str(ctx.PLUGIN().getText()).strip()
+        if pluginName.startswith("_"):
+            pluginName = pluginName[1:]
+        parsedObject.update({"pluginName": pluginName})
+
+        pluginArgs = []
+        if ctx.PLUGIN_EXPRESSION() is not None:
+            for expression in ctx.PLUGIN_EXPRESSION():
+                if expression is not None:
+                    arg = str(expression.getText())
+                    if arg.startswith('"') and arg.endswith('"'):
+                        arg = arg[1:-1]
+                    elif arg.startswith("'") and arg.endswith("'"):
+                        arg = arg[1:-1]
+                    pluginArgs.append(arg)
+        parsedObject.update(
+            {"pluginArgs": pluginArgs}
+        )
+
+        # 获取错误代码
+        errorCode = 0
+        errorMsg = None
+        if ctx.exception is not None:
+            errorCode = -1
+            errorMsg = ctx.exception.message
+
+        self.parsedObject = parsedObject
+        self.errorCode = errorCode
+        self.errorMsg = errorMsg
