@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 import copy
-import time
 import os
 import re
 from collections import namedtuple
+from ..common import rewriteStatement
 
 # 默认的比较选项
 compareDefaultOption = {
@@ -243,15 +243,15 @@ class POSIXCompare:
         return compare_result, m_CompareDiffResult
 
     def compare_text_files(self, file1, file2,
-                           skipLines=None,
-                           maskLines=None,
-                           ignoreEmptyLine=False,
-                           CompareWithMask=None,
-                           CompareIgnoreCase=False,
-                           CompareIgnoreTailOrHeadBlank=False,
-                           CompareWorkEncoding='UTF-8',
-                           CompareRefEncoding='UTF-8',
-                           compareAlgorithm='MYERS'):
+                           skipLines: list = None,
+                           maskLines: dict = None,
+                           ignoreEmptyLine: bool = False,
+                           CompareWithMask: bool = True,
+                           CompareIgnoreCase: bool = False,
+                           CompareIgnoreTailOrHeadBlank: bool = False,
+                           CompareWorkEncoding: str = 'UTF-8',
+                           CompareRefEncoding: str = 'UTF-8',
+                           compareAlgorithm: str = 'MYERS'):
         if not os.path.isfile(file1):
             raise DiffException('ERROR: File %s does not exist!' % file1)
         if not os.path.isfile(file2):
@@ -447,7 +447,7 @@ class POSIXCompare:
         return compareResult, newCompareResultList
 
 
-def executeCompareRequest(requestObject):
+def executeCompareRequest(cls, requestObject, commandScriptFile: str):
     global compareOption
     global compareDefaultOption
     global compareMaskLines
@@ -587,6 +587,9 @@ def executeCompareRequest(requestObject):
         targetFile = str(requestObject["targetFile"])
         referenceFile = str(requestObject["referenceFile"])
 
+        # 处理targetFile和referenceFile的变量替换
+        targetFile = rewriteStatement(cls=cls, statement=targetFile, commandScriptFile=commandScriptFile)
+        referenceFile = rewriteStatement(cls=cls, statement=referenceFile, commandScriptFile=commandScriptFile)
         compareHandler = POSIXCompare()
         try:
             compareResult, compareReport = \
