@@ -30,6 +30,8 @@ helpMessage = [
             
             _LOAD PLUGIN <plugin file location> 
 
+            _LOAD SCRIPT <script file location> 
+
             _LOAD MAP <command mapping file location>
         ''',
     },
@@ -230,6 +232,44 @@ helpMessage = [
                 %}
             ''',
     },
+    {
+        "topic": 'MONITOR',
+        "summary": "Monitor system perference.",
+        "nameSpace": "ALL",
+        "synatx":
+            '''
+        _MONITOR MANAGER ON [WOKERS <int>]
+        _MONITOR MANAGER OFF
+        _MONITOR CREATE TASK <taskName> TAG=<taskTag> <taskPara1>=<taskValue1> <taskPara2>=<taskValue2> ...
+        _MONITOR START TASK [ <taskName> | ALL ]
+        _MONITOR STOP TASK [ <taskName> | ALL ]
+        _MONITOR REPORT TASK [ <taskName> | ALL ]
+        _MONITOR LIST TASK
+
+        Example:
+            _MONITOR MONITORMANAGER ON WORKERS 3;
+
+            _MONITOR CREATE TASK task1 TAG=cpu_count;
+            _MONITOR CREATE TASK task2 TAG=memory FREQ=10;
+            _MONITOR CREATE TASK task3 TAG=network NAME='eth0' FREQ=10;
+            _MONITOR CREATE TASK task4 TAG=disk NAME='.*' FREQ=10;
+            _MONITOR CREATE TASK task5 TAG=process USERNAME='ldb' EXE='.*grassland-launcher';
+            _MONITOR START TASK ALL;
+            _SLEEP 10;
+            _MONITOR LIST TASK;
+            _MONITOR REPORT TASK ALL;
+
+        Supported tags:
+            cpu_count                
+            cpu_count_physical
+            cpu_times
+            cpu_percent
+            memory
+            network
+            disk
+            process
+            ''',
+    },
     {
         "topic": 'SPOOL',
         "summary": "Print subsequent run commands and results to the specified file.",
@@ -242,6 +282,30 @@ helpMessage = [
                 _SPOOL OFF
             ''',
     },
+    {
+        "topic": 'IF',
+        "summary": "Conditional statement.",
+        "nameSpace": "ALL",
+        "synatx":
+            '''
+                _IF {% <expression> %}                
+                _ENDIF
+            ''',
+    },
+    {
+        "topic": 'LOOP',
+        "summary": "LOOP statement.",
+        "nameSpace": "ALL",
+        "synatx":
+            '''
+               _LOOP BEGIN UNTIL {% <expression> %}
+               _LOOP BREAK
+               _LOOP CONTINUE
+               _LOOP END
+               
+               _LOOP [<maxRetriedTime>] UNTIL {% <expression> %} INTERVAL <loop interval time>
+            ''',
+    },
     {
         "topic": 'CONNECT',
         "summary": "Connect to JDBC database.",
@@ -260,42 +324,140 @@ helpMessage = [
             ''',
     },
     {
-        "topic": 'MONITOR',
-        "summary": "Monitor system perference.",
-        "nameSpace": "ALL",
+        "topic": 'SQL',
+        "summary": "Execute sql statement.",
+        "nameSpace": "SQL",
         "synatx":
             '''
-        _MONITOR MANAGER ON [WOKERS <int>]
-        _MONITOR MANAGER OFF
-        _MONITOR CREATE TASK <taskName> TAG=<taskTag> <taskPara1>=<taskValue1> <taskPara2>=<taskValue2> ...
-        _MONITOR START TASK [ <taskName> | ALL ]
-        _MONITOR STOP TASK [ <taskName> | ALL ]
-        _MONITOR REPORT TASK [ <taskName> | ALL ]
-        _MONITOR LIST TASK
+        Write any valid sql statement.
+        
+        For single line sql statement, end with semicolon;
+        For multiline statements, end with a slash;
         
         Example:
-            _MONITOR MONITORMANAGER ON WORKERS 3;
-            
-            _MONITOR CREATE TASK task1 TAG=cpu_count;
-            _MONITOR CREATE TASK task2 TAG=memory FREQ=10;
-            _MONITOR CREATE TASK task3 TAG=network FILTER='eth0' FREQ=10;
-            _MONITOR CREATE TASK task4 TAG=disk FILTER='.*' FREQ=10;
-            _MONITOR CREATE TASK task5 TAG=process USERNAME='ldb' EXE='.*grassland-launcher';
-            _MONITOR START TASK ALL;
-            _SLEEP 10;
-            _MONITOR LIST TASK;
-            _MONITOR REPORT TASK ALL;
+            Drop Table If Exists Col1;
 
-        Supported tags:
-            cpu_count                
-            cpu_count_physical
-            cpu_times
-            cpu_percent
-            memory
-            network
-            disk
-            process
+            Create Table TestTab(Col1 Int);
+
+            Declare
+            Begin
+                Insert Into TestTab Values(1);
+            End;
+            /
             ''',
+    },
+    {
+        "topic": 'SQLSESSION',
+        "summary": "SQL session management.",
+        "nameSpace": "SQL",
+        "synatx":
+            '''
+        _SESSION SAVE <sessonName>
+        _SESSION RELEASE
+        _SESSION RESTORE <sessonName>
+        _SESSION SAVEURL [<sessonName>]
+        _SESSION SHOW [<sessonName>]
 
+        Example:
+            N/A
+            ''',
+    },
+    {
+        "topic": 'HTTPSET',
+        "summary": "Set http request behavior.",
+        "nameSpace": "API",
+        "synatx":
+            '''
+        SET HTTPS_VERIFY <ON|OFF>;
+        SET HTTP_RPXOY <proxy_address, like http://127.0.0.1:8080>
+        
+    
+        Example:
+            N/A
+            ''',
+    },
+    {
+        "topic": 'HTTP',
+        "summary": "Execute http statement.",
+        "nameSpace": "API",
+        "synatx":
+            '''
+        Execute http request.
+
+        To compose an HTTP request in TestCli, use the following general syntax:            
+            ### RequestName
+            Method Request-URI HTTP-Version
+            Header-field: Header-value
+
+            Request-Body
+            ###
+            
+        Use comments in HTTP requests:
+            -- Comment Here.
+            GET http://example.com/a/
+
+        Use multipart/form-data content type:
+            POST http://example.com/api/upload HTTP/1.1
+            Content-Type: multipart/form-data; boundary=boundary
+            
+            --boundary
+            Content-Disposition: form-data; name="first"; filename="input.txt"
+            
+            // The 'input.txt' file will be uploaded
+            < ./input.txt
+            
+            --boundary
+            Content-Disposition: form-data; name="second"; filename="input-second.txt"
+            
+            // A temporary 'input-second.txt' file with the 'Text' content will be created and uploaded
+            Text
+            --boundary
+            Content-Disposition: form-data; name="third";
+            
+            // The 'input.txt' file contents will be sent as plain text.
+            < ./input.txt --boundary--
+            
+        Example:
+            ### basic request 1
+            -- A basic request
+            GET http://example.com/a/  HTTP/1.1
+
+            ###
+
+            ### basic request 2
+            -- A basic request
+            GET http://example.com:8080  HTTP/1.1
+                /api
+                /html
+                /get
+                ?id=123
+                &value=content
+    
+            ###
+
+            ### basic request 3
+            POST http://example.com:8080/api/html/post HTTP/1.1
+            Content-Type: application/json
+            Cookie: key=first-value
+            
+            { "key" : "value", "list": [1, 2, 3] }
+            ###
+
+            ''',
+    },
+    {
+        "topic": 'HTTPSESSION',
+        "summary": "Http session management.",
+        "nameSpace": "API",
+        "synatx":
+            '''
+           _SESSION SAVE <sessonName>
+           _SESSION RELEASE
+           _SESSION RESTORE <sessonName>
+           _SESSION SHOW [<sessonName>]
+        
+        Example:
+            N/A
+            ''',
     }
 ]
